Arch-abstraction:  renamed "vg_skin.h" as "tool.h".  Kept a residual vg_skin.h
(which just #includes tool.h) for backward-compatibility.


git-svn-id: svn://svn.valgrind.org/valgrind/trunk@2647 a5019735-40e9-0310-863c-91ae7b9d1cf9
diff --git a/coregrind/docs/coregrind_tools.html b/coregrind/docs/coregrind_tools.html
index 7fc0b53..20b42a3 100644
--- a/coregrind/docs/coregrind_tools.html
+++ b/coregrind/docs/coregrind_tools.html
@@ -462,7 +462,7 @@
 reading suppressions from a suppressions file, etc.  While writing these
 functions requires some work, it's much less than doing error handling from
 scratch because the core is doing most of the work.  See the type
-<code>VgNeeds</code> in <code>include/vg_skin.h</code> for full details of all
+<code>VgNeeds</code> in <code>include/tool.h</code> for full details of all
 the needs.<p>
 
 Third, the tool can indicate which events in core it wants to be notified
@@ -478,7 +478,7 @@
 time this happens.<p>
 
 More information about ``details'', ``needs'' and ``trackable events'' can be
-found in <code>include/vg_skin.h</code>.<p>
+found in <code>include/tool.h</code>.<p>
 
 <a name="instr"></a>
 <h3>2.8&nbsp; Instrumentation</h3>
@@ -512,20 +512,20 @@
 not brilliantly documented.  Here are some important points, but there are
 undoubtedly many others that I should note but haven't thought of.<p>
 
-The file <code>include/vg_skin.h</code> contains all the types,
+The file <code>include/tool.h</code> contains all the types,
 macros, functions, etc. that a tool should (hopefully) need, and is the only
 <code>.h</code> file a tool should need to <code>#include</code>.<p>
 
 In particular, you probably shouldn't use anything from the C library (there
 are deep reasons for this, trust us).  Valgrind provides an implementation of a
 reasonable subset of the C library, details of which are in
-<code>vg_skin.h</code>.<p>
+<code>tool.h</code>.<p>
 
 Similarly, when writing a tool, you shouldn't need to look at any of the code
 in Valgrind's core.  Although it might be useful sometimes to help understand
 something.<p>
 
-<code>vg_skin.h</code> has a reasonable amount of documentation in it that
+<code>tool.h</code> has a reasonable amount of documentation in it that
 should hopefully be enough to get you going.  But ultimately, the tools
 distributed (Memcheck, Addrcheck, Cachegrind, Lackey, etc.) are probably the
 best documentation of all, for the moment.<p>
@@ -581,7 +581,7 @@
 GDB.<p>
 
 If you just want to know whether a program point has been reached, using the
-<code>OINK</code> macro (in <code> include/vg_skin.h</code>) can be easier than
+<code>OINK</code> macro (in <code> include/tool.h</code>) can be easier than
 using GDB.<p>
 
 If you are having problems with your UCode instrumentation, it's likely that
@@ -689,7 +689,7 @@
 <code>VGP_(register_profile_event)()</code> and then use the
 <code>VGP_PUSHCC</code> and <code>VGP_POPCC</code> macros to record time spent
 doing certain things.  New profiling event numbers must not overlap with the
-core profiling event numbers.  See <code>include/vg_skin.h</code> for details
+core profiling event numbers.  See <code>include/tool.h</code> for details
 and Memcheck for an example.
 
 
diff --git a/coregrind/gen_toolint.pl b/coregrind/gen_toolint.pl
index bc02cbe..edd716d 100644
--- a/coregrind/gen_toolint.pl
+++ b/coregrind/gen_toolint.pl
@@ -140,7 +140,7 @@
     };
     $indent = "   ";
 } elsif ($output eq "initfunc") {
-    $include = "vg_skin.h";
+    $include = "tool.h";
     $generate = sub ($$$@) {
 	my ($pfx, $ret, $func, @args) = @_;
 	my $args = join ", ", @args;
diff --git a/coregrind/vg_errcontext.c b/coregrind/vg_errcontext.c
index d53f712..f61668b 100644
--- a/coregrind/vg_errcontext.c
+++ b/coregrind/vg_errcontext.c
@@ -67,7 +67,7 @@
 /* Errors.  Extensible (via the 'extra' field).  Tools can use a normal
    enum (with element values in the normal range (0..)) for `ekind'. 
    Functions for getting/setting the tool-relevant fields are in
-   include/vg_skin.h.
+   include/tool.h.
 
    When errors are found and recorded with VG_(maybe_record_error)(), all
    the tool must do is pass in the four parameters;  core will
@@ -140,7 +140,7 @@
    SuppLocTy;
 
 /* Suppressions.  Tools can get/set tool-relevant parts with functions
-   declared in include/vg_skin.h.  Extensible via the 'extra' field. 
+   declared in include/tool.h.  Extensible via the 'extra' field. 
    Tools can use a normal enum (with element values in the normal range
    (0..)) for `skind'. */
 struct _Supp {
diff --git a/coregrind/vg_instrument.c b/coregrind/vg_instrument.c
index 78d0a09..8df8c78 100644
--- a/coregrind/vg_instrument.c
+++ b/coregrind/vg_instrument.c
@@ -29,11 +29,11 @@
    The GNU General Public License is contained in the file COPYING.
 */
 
-/* We only import vg_skin.h here, because this file only provides functions
+/* We only import tool.h here, because this file only provides functions
    for doing things that could be done directly by the tool -- it's just to
    make tools' lives easier, rather than let them do something they
    couldn't otherwise do. */
-#include "vg_skin.h"
+#include "tool.h"
 
 
 void VG_(lit_to_reg)(UCodeBlock* cb, UInt lit, UInt t)
diff --git a/coregrind/vg_symtab2.h b/coregrind/vg_symtab2.h
index 1f25a11..09c75bb 100644
--- a/coregrind/vg_symtab2.h
+++ b/coregrind/vg_symtab2.h
@@ -118,7 +118,7 @@
 #define STRCHUNKSIZE	(64*1024)
 
 /* A structure which contains information pertaining to one mapped
-   text segment. (typedef in vg_skin.h) */
+   text segment. (typedef in tool.h) */
 struct _SegInfo {
    struct _SegInfo* next;	/* list of SegInfos */
diff --git a/coregrind/core.h b/coregrind/core.h
index 4b55377..bbcdf32 100644
--- a/coregrind/core.h
+++ b/coregrind/core.h
@@ -43,10 +43,10 @@
 
 #include "vg_constants.h"
 
 /* All stuff visible to core and tools goes in vg_skin.h.  Things
  * visible to core but not visible to any tools should go in this
  * file, core.h. */
-#include "vg_skin.h"
+#include "tool.h"
 #include "valgrind.h"
 
 #undef SK_
@@ -285,7 +285,7 @@
    ------------------------------------------------------------------ */
 /* These structs are not exposed to tools to mitigate possibility of
    binary-incompatibilities when the core/tool interface changes.  Instead,
-   set functions are provided (see include/vg_skin.h). */
+   set functions are provided (see include/tool.h). */
 typedef
    struct {
       Char* name;
@@ -1619,7 +1619,7 @@
 /* This thread's TLS pointer. */
 extern Int VGOFF_(tls_ptr);
 
 /* Nb: Most helper offsets are in include/vg_skin.h, for use by tools */
 
 extern Int VGOFF_(helper_undefined_instruction);
 
@@ -43,10 +43,10 @@
 #include "vg_constants.h"
 
-/* All stuff visible to core and tools goes in vg_skin.h.  Things
+/* All stuff visible to core and tools goes in tool.h.  Things
  * visible to core but not visible to any tools should go in this
  * file, core.h. */
@@ -1619,7 +1619,7 @@
 extern Int VGOFF_(tls_ptr);
 
-/* Nb: Most helper offsets are in include/vg_skin.h, for use by tools */
+/* Nb: Most helper offsets are in include/tool.h, for use by tools */
 
 extern Int VGOFF_(helper_undefined_instruction);